@@ -44,6 +44,7 @@ class Calendar;
 */
 class KCALCORE_EXPORT FileStorage : public CalStorage
 {
+    Q_OBJECT
 public:
 
     /**
@@ -64,12 +65,12 @@ public:
     */
     explicit FileStorage(const Calendar::Ptr &calendar,
                          const QString &fileName = QString(),
-                         KCalCore::CalFormat *format = 0);
+                         KCalCore::CalFormat *format = nullptr);
 
     /**
       Destructor.
     */
-    virtual ~FileStorage();
+    ~FileStorage() override;
 
     /**
       Sets the name of the file that contains the calendar data.
@@ -105,22 +106,22 @@ public:
     /**
       @copydoc CalStorage::open()
     */
-    bool open() Q_DECL_OVERRIDE;
+    bool open() override;
 
     /**
       @copydoc CalStorage::load()
     */
-    bool load() Q_DECL_OVERRIDE;
+    bool load() override;
 
     /**
       @copydoc CalStorage::save()
     */
-    bool save() Q_DECL_OVERRIDE;
+    bool save() override;
 
     /**
       @copydoc CalStorage::close()
     */
-    bool close() Q_DECL_OVERRIDE;
+    bool close() override;
 
 private:
     //@cond PRIVATE
